@@ -5,7 +5,6 @@ import asyncio
 import logging
 import psutil
 
-# constants
 HEADERS = {"Content-Type": "application/json"}
 STAT_ENDPOINT = "https://api.statcord.com/v3/stats"
 
@@ -65,7 +64,7 @@ class StatcordClient:
         return "".join(traceback.format_exception(type(e), e, e.__traceback__, 4))
 
     def _get_user_count(self) -> int:
-        "Gets the user count of the bot as accurately as it can." ""
+        """Gets the user count of the bot as accurately as it can."""
 
         if self.bot.intents.members or self.bot.intents.presences:
             return len(self.bot.users)
@@ -108,6 +107,15 @@ class StatcordClient:
 
             await asyncio.sleep(60)
 
+    async def _call_custom_graph(self, callable) -> object:
+        if self.custom_2 is None:
+            return 0
+
+        if asyncio.iscoroutinefunction(self.custom_2):
+            return await callable()
+                
+        return callable()
+
     async def post_stats(self) -> None:
         """Helper method used to actually post the stats to Statcord."""
 
@@ -126,27 +134,14 @@ class StatcordClient:
         period_net_usage = str(total_net_usage - self._prev_net_usage)  # net usage to be sent
         self._prev_net_usage = total_net_usage  # update previous net usage counter
 
-        if self.custom_1 is not None:
-            if asyncio.iscoroutinefunction(self.custom_1):
-                custom_1_value = await self.custom_1()
-            else:
-                custom_1_value = self.custom_1()
-        else:
-            custom_1_value = 0
-
-        if self.custom_2 is not None:
-            if asyncio.iscoroutinefunction(self.custom_2):
-                custom_2_value = await self.custom_2()
-            else:
-                custom_2_value = self.custom_2()
-        else:
-            custom_2_value = 0
+        custom_1_value = self._call_custom_graph(self.custom_1)
+        custom_2_value = self._call_custom_graph(self.custom_2)
 
         data = {
             "id": str(self.bot.user.id),
             "key": self.statcord_key,
             "servers": str(len(self.bot.guilds)),  # server count
-            "users": str(len(self.bot.users)),  # user count
+            "users": str(self._get_user_count()),  # user count
             "commands": str(self._command_count),  # command count
             "active": list(self._active_users),
             "popular": [{"name": k, "count": v} for k, v in self._popular_commands.items()],  # active commands
